from distutils.core import setup
setup(
  name = 'xy_textfeel',
  packages = ['xy_textfeel'],
  version = '1.0.0',
  description = 'text feel Analyze',
  long_description='text feel Analyze',
  author = 'KingHS',
  author_email = '382771946@qq.com',
  keywords = ['pip3', 'python3','python','text feel','feeling'],
  license='MIT',
  install_requires=['requests']
)
